%% histScaling
% A short tutorial on making histograms with matching bin sizes. Run the
% script and compare the output with the code sections.

%% Update History
% Written December 2, 2013 by Beth Haas - 1.0.0

%% Parameters
nBins = 20;
% Set Extrema
minY = 0; %make sure there are no values lower than this
maxY = 50; %make sure there are no values higher than this

%%
figure('Color', 'w', 'Position', [300 400 700 500]);

%% 1 - Generate datapoints
x = 1:100;
meanY = 20;
stdevY = 5;
yA = randn(size(x))*stdevY + meanY; %one set of datapoints
yB = randn(size(x))*stdevY + meanY; %another set of datapoints

% Plot datapoints
subplot(2, 2, 1:2)

hold all
plot(x, yA, 'b.')
plot(x, yB, 'r.')
hold off

% Labels
t1 = sprintf('100 datapoints from N(%d, %d)', meanY, stdevY);
title(t1, 'FontSize', 16)
ylabel('value', 'FontSize', 12)
legend({'A', 'B'})
set(gca, 'FontSize', 12)

%% 2 - Autoscaled histogram
% This is what Matlab does by default

% Bin data
[countsA, binsA] = hist(yA, nBins);
[countsB, binsB] = hist(yB, nBins);

% Plot histograms
subplot(2, 2, 3)

hold all
bar(binsA, countsA, 'b')
bar(binsB, countsB, 'r')
hold off

% Labels
set(gca, 'XLim', [minY maxY])
title('20-bin auto histogram', 'FontSize', 16)
xlabel('y value', 'FontSize', 12)
ylabel('counts', 'FontSize', 12)
legend({'A', 'B'})
set(gca, 'FontSize', 12)

%% 3 - Scale-adjusted histogram
% This generates histograms you can compare easily

% Add in extrema placeholders to adjust bins
yA2 = [yA minY maxY];
yB2 = [yB minY maxY];

% Bin data
[countsA2, binsA2] = hist(yA2, nBins);
[countsB2, binsB2] = hist(yB2, nBins);

subplot(2, 2, 4)

% Remove extrema placeholders from counts
histEndsA = zeros(size(binsA2));
histEndsA(1) = 1; %removes minimum placeholder
histEndsA(end) = 1; %removes maximum placeholder

% Repeat for dataset B
histEndsB = zeros(size(binsB2));
histEndsB(1) = 1;
histEndsB(end) = 1;

countsA3 = countsA2 - histEndsA;
countsB3 = countsB2 - histEndsB;

% Plot histograms
hold all
bar(binsA2, countsA3, 'b')
bar(binsB2, countsB3, 'r')
hold off

% Labels
set(gca, 'XLim', [minY maxY])
t3 = sprintf('20-bin histogram scaled (%d to %d)', minY, maxY);
title(t3, 'FontSize', 16)
xlabel('y value', 'FontSize', 12)
ylabel('counts', 'FontSize', 12)
legend({'A', 'B'})
set(gca, 'FontSize', 12)

%% Comment text
s = sprintf(['Notice that the bars' '\n' ...
    'are the same width ' '\n'...
    'AND they line up!']);
text(30, 12, s, 'FontSize', 12)